DynamicMapping

Struct DynamicMapping 

pub struct DynamicMapping<K: Eq + Hash + Clone + Send + Sync + 'static> { /* private fields */ }
Similar to floodgate::FixedMapping, except that each cooldown can have a different capacity and/or period.

For some method documentation, please see floodgate::JumpingWindow.

Implementations

Source

impl<K: Eq + Hash + Clone + Send + Sync + 'static> DynamicMapping<K>

pub fn new(cycle_period: Duration) -> Self

Create a new DynamicMapping.

Arguments
  • cycle_period - How often to cycle the mapping. Must be greater than the period of any cooldown this mapping contains.
pub fn tokens(&self, key: &K, capacity: u64, period: Duration) -> u64

pub fn next_reset(&self, key: &K, capacity: u64, period: Duration) -> Duration

pub fn retry_after( &self, key: &K, capacity: u64, period: Duration, ) -> Option<Duration>

pub fn can_trigger(&self, key: &K, capacity: u64, period: Duration) -> bool

pub fn trigger( &self, key: &K, capacity: u64, period: Duration, ) -> Option<Duration>

pub fn reset(&self, key: &K, capacity: u64, period: Duration)

pub fn cycle(&self) -> bool

Cycles the mapping. Returns true if it cycled, or false if not.

pub fn start(mapping: Arc<Self>)

Start the background cycler. Failing to do this will result in a memory leak.

If, for some reason, you don’t want to use the default cycler, you must manually call the .cycle method on the mapping periodically.

Arguments
  • mapping - The DynamicMapping, wrapped in an Arc.